@@ -14,14 +14,14 @@ use odbc_api::{
     ColumnDescription, Cursor, DataType, Environment, IntoParameter, Nullability,
 };
 use parquet::{
-    basic::{Compression, ConvertedType, Repetition, Type as PhysicalType},
+    basic::{Compression, ConvertedType, Encoding, Repetition, Type as PhysicalType},
     column::writer::ColumnWriter,
     errors::ParquetError,
     file::{
         properties::WriterProperties,
         writer::{FileWriter, RowGroupWriter, SerializedFileWriter},
     },
-    schema::types::{Type, TypePtr},
+    schema::types::{ColumnPath, Type, TypePtr},
 };
 
 use crate::{open_connection, parquet_buffer::ParquetBuffer, QueryOpt};
@@ -44,6 +44,7 @@ pub fn query(environment: &Environment, opt: &QueryOpt) -> Result<(), Error> {
         encoding,
         prefer_varbinary,
         column_compression_default,
+        parquet_column_encoding,
     } = opt;
 
     // Convert the input strings into parameters suitable to for use with ODBC.
@@ -67,15 +68,20 @@ pub fn query(environment: &Environment, opt: &QueryOpt) -> Result<(), Error> {
         }
     };
 
+    let parquet_format_options = ParquetFormatOptions {
+        column_compression_default: *column_compression_default,
+        column_encodings: parquet_column_encoding.clone(),
+    };
+
     if let Some(cursor) = odbc_conn.execute(query, params.as_slice())? {
         cursor_to_parquet(
             cursor,
             output,
             batch_size,
             *batches_per_file,
-            *column_compression_default,
             encoding.use_utf16(),
             *prefer_varbinary,
+            parquet_format_options,
         )?;
     } else {
         eprintln!(
@@ -85,14 +91,20 @@ pub fn query(environment: &Environment, opt: &QueryOpt) -> Result<(), Error> {
     Ok(())
 }
 
+/// Options influencing the output parquet format.
+struct ParquetFormatOptions {
+    column_compression_default: Compression,
+    column_encodings: Vec<(String, Encoding)>,
+}
+
 fn cursor_to_parquet(
     cursor: impl Cursor,
     path: &Path,
     batch_size: BatchSizeLimit,
     batches_per_file: u32,
-    column_compression_default: Compression,
     use_utf16: bool,
     prefer_varbinary: bool,
+    parquet_format_options: ParquetFormatOptions,
 ) -> Result<(), Error> {
     let (parquet_schema, buffer_description) = make_schema(&cursor, use_utf16, prefer_varbinary)?;
 
@@ -148,7 +160,7 @@ fn cursor_to_parquet(
         batch_size_row,
         parquet_schema.clone(),
         batches_per_file,
-        column_compression_default,
+        parquet_format_options,
     )?;
 
     while let Some(buffer) = row_set_cursor.fetch()? {
@@ -570,14 +582,18 @@ impl<'p> ParquetWriter<'p> {
         batch_size: u32,
         schema: Arc<Type>,
         batches_per_file: u32,
-        column_compression_default: Compression,
+        format_options: ParquetFormatOptions,
     ) -> Result<Self, Error> {
         // Write properties
         // Seems to also work fine without setting the batch size explicitly, but what the heck. Just to
         // be on the safe side.
-        let wpb = WriterProperties::builder()
+        let mut wpb = WriterProperties::builder()
             .set_write_batch_size(batch_size as usize)
-            .set_compression(column_compression_default);
+            .set_compression(format_options.column_compression_default);
+        for (column_name, encoding) in format_options.column_encodings {
+            let col = ColumnPath::new(vec![column_name]);
+            wpb = wpb.set_column_encoding(col, encoding)
+        }
         let properties = Arc::new(wpb.build());
         let file = if batches_per_file == 0 {
             File::create(path)?
